# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-29 21:27
from __future__ import unicode_literals

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('workflow', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='statecontrollerdata',
            name='data',
            field=jsonfield.fields.JSONField(default=dict, verbose_name='State Data'),
        ),
        migrations.AlterField(
            model_name='statemachine',
            name='representation',
            field=jsonfield.fields.JSONField(help_text='Graphic representation of the FSM graph in JSON.', null=True, verbose_name='Representation'),
        ),
    ]
